@@ -1,4 +1,4 @@
-from spyderbi import translate
+from translate import translate
 import getdata
 import requests
 import json
@@ -13,19 +13,19 @@ class video():
             else:
                 self.av = i
         if self.av!="" and self.bv =="":
-                self.bv = translate.enc(self.av)
+                self.bv = translate().enc(self.av)
 
         if self.bv!="" and self.av =="":
-                self.av = translate.dec(self.bv)
+                self.av = translate().dec(self.bv)
 
 
     def getav(self,av):
         self.av = av
-        self.bv = translate.enc(self.av)
+        self.bv = translate().enc(self.av)
 
     def getbv(self,bv):
         self.bv = av
-        self.av = translate.dec(self.bv)
+        self.av = translate().dec(self.bv)
 
     def putav(self):
         return self.av
